@@ -1,6 +1,6 @@
 package File::Rotate::Simple;
 
-use Moo;
+use Moo 1.001000;
 
 use Path::Tiny;
 use Types::Standard -types;
@@ -8,7 +8,7 @@ use Types::Standard -types;
 use namespace::autoclean;
 
 use version;
-$File::Rotate::Simple::VERSION = version->declare('v0.1.3');
+$File::Rotate::Simple::VERSION = version->declare('v0.1.4');
 
 =head1 NAME
 
@@ -200,6 +200,20 @@ sub rotate {
 
 =for readme continue
 
+=head1 SEE ALSO
+
+The following modules have similar functionality:
+
+=over
+
+=item * L<File::Rotate::Backup>
+
+=item * L<File::Write::Rotate>
+
+=back
+
+There are also several logging modueles that support log rotation.
+
 =head1 AUTHOR
 
 Robert Rothenberg, C<rrwo@cpan.org>
